#
# spec file for package highlighting-kate
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name highlighting-kate
%bcond_with tests
Name:           %{pkg_name}
Version:        0.6.4
Release:        1.12
Summary:        Syntax highlighting
License:        GPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pcre-light-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-utf8-string-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-process-devel
%endif

%description
Highlighting-kate is a syntax highlighting library with support for nearly one
hundred languages. The syntax parsers are automatically generated from Kate
syntax descriptions (<http://kate-editor.org/>), so any syntax supported by
Kate can be added. An (optional) command-line program is provided, along with a
utility for generating new parsers from Kate XML syntax descriptions.
__This library has been deprecated. Please use skylighting instead.__.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%define cabal_configure_options -fexecutable -fpcre-light
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%defattr(-,root,root,-)
%doc LICENSE
%doc README.md changelog
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%defattr(-,root,root,-)
%doc README.md changelog

%changelog
* Sun Feb  5 2017 psimons@suse.com
- Update to version 0.6.4 with cabal2obs.
* Fri Sep 30 2016 psimons@suse.com
- Update to version 0.6.3 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.2.1 revision 0 with cabal2obs.
* Sun Jul  3 2016 mimi.vx@gmail.com
- update to 0.6.2.1
  * * Use `#pop` instead of `#stay` if `fallthrough` is true but
  no `fallthroughContext` is given.
  * Use stack for default build (Makefile), document stack build
    procedure.
* Sun Mar 20 2016 mimi.vx@gmail.com
- update to 0.6.2
- drop add-rpmspec-syntax.patch -- need rework
  * Added support for WordDetect.
  * Added hamlet.
  * Added elixir (supernullset).
* Sun Dec 13 2015 mimi.vx@gmail.com
- update to 0.6.1
- refreshed add-rpmspec-syntax.patch
  * Don't use auto-all in ghc-prof-options.
  * Removed splitBase flag and ability to compile on base < 4.4.
  * Add agda tests with unicode input
  * Fix 'Text.Regex.PCRE.Light: Error in regex: invalid UTF-8 string'
    error message.
  * Reapplied isocpp.xml.patch.
  * Added `languageByFullName` (API change).  Changed behavior of
    `highlightAs` so that languages can match on "full official name"
    as well as the canonical name (derived from the xml filename.
    Previously, only `cs` worked for C#.  Now you may use `C#` as
    well.
  * Allow `csharp` as a special-case alias for `cs`.
  * Added support for llvm.
* Tue Jun  2 2015 mimi.vx@gmail.com
- refreshed add-rpmspec-syntax.patch
  Sun May 31 15:05:40 UTC 2015 - mimi.vx@gmail.com
- update to 0.6
- disabled add-rpmspec-syntax.patch
  * Support new KF5 token attributes (#69).
  * Added to TokenType: ConstantTok, SpecialCharTok, VerbatimStringTok, SpecialStringTok, ImportTok, DocumentationTok, AnnotationTok, CommentVarTok, VariableTok, ControlFlowTok, OperatorTok, BuiltInTok, ExtensionTok, PreprocessorTok, AttributeTok, InformationTok, WarningTok.
  * Revised styles to add clauses for the new TokenTypes.
  * Revised HTML formatter to produce CSS for all the new TokenTypes, and to include comments naming each type.
  * Modified ParseSyntaxFiles to handle new types.
  * Updated tests.
  * Updated xml syntax definitions. However, we retain an older version of haskell.xml, since the new one didn't work properly.
  * Added ToColor instance for Int.
  * Renamed Highlight[.hs] to highlighting-kate[.hs] (Geoff Nixon).
  * Allow # as an operator in Haskell (Ryan Yates).
  * Added support for Kotlin (kotlinlang.org) (Sebastien Soudan).
  * Rename Highlight utility and Highlight.hs to highlighting-kate and highlighting-kate.hs to avoid naming conflicts with other syntax highlighting utilities.
  * Put code blocks in a div. This reverts the change in 0.5.13, wrapping all blocks in a pre element. (Pre elements are only supposed to contain flow content, not block-level elements like tables.) Instead we now wrap each code block in a div with class sourceCode.
  * The default CSS now includes div.sourceCode { x-overflow: auto; }, so that a scroll bar will appear on small screens. See jgm/pandoc#1903 and jgm/highlighting-kate#65 for background.
  * Wrap HTML table with line numbers in a pre element (Adam Sapek). HTML tables are impossible to format via styles for different screen widths. This means that pandoc generated pages with code blocks must have a fixed minimal width, making them hard to read on narrower screens.
  * Wrapping the table in a pre block allows formatting of code blocks to have a horizontal scroll bar if the content doesn't fit the screen width, by adding the following style:
    pre.sourceCode {
    overflow-x: auto;
    }
  * This enables pandoc to generate responsive HTML pages.
* Thu May 14 2015 mimi.vx@gmail.com
- correct post/postun and deps section
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 0.5.12
- refresh add-rpmspec-syntax.patch
  * Added Data and Typeable instances for types used in pandoc's
    ReaderOptions and WriterOptions (Shahbaz Youssefi).
  * Bumped blaze-html upper bounds (RyanGlScott).
  * Added idris syntax definition (Alexander Shabalin).
  * Added regex-posix install to 'make prep' step (@johguenther).
  * Modified isocpp.xml to fix float parsing. The float regex in
    isocpp.xml seems to work fine with Kate's regex engine, but gives
    different results with pcre. Added isocpp.xml.patch to keep track of
    the divergence from upstream.
  * Fixed rest.xml regex (#54).
  * Fixed line continuations (#51).
    API change:  Added synStContinuation field to SyntaxState.
  * Added Dockerfile syntax (James Turnbull, #49).
  * Fixed 'prep' target in Makefile.
  * Added support for Agda (Matthias C. M. Troffaes).
  * Made doctype case-insensitive in HTML 5 (Ondřej Žára).
* Tue Apr  7 2015 peter.trommler@ohm-hochschule.de
- go back to "ordinary" build
  * optimization level changed in ghc-rpm-macros
  * fixes build with versioned html doc dirs
* Thu Sep 25 2014 peter.trommler@ohm-hochschule.de
- update to 0.5.9
  * disable optimization despite ticket marked as fixed
  * memory usage still too high for OBS
  * see https://ghc.haskell.org/trac/ghc/ticket/8980
- refresh add-rpmspec-syntax.patch
* Thu Mar 27 2014 sbahling@suse.com
- Correct package license
* Sun Mar 16 2014 sbahling@suse.com
- Update to 0.5.6.1  from upstream
  * Allow blaze-html 0.7
  * Added restructuredtext.
  * Updated rust syntax definition.
  * Changed lua highlighting so variables/constants not highlighted
    as keywords.
  * Updated kate syntax definitions for python, cmake.
- Add add-rpmspec-syntax.patch for support of RPM spec file\
  highlighting
* Thu Sep 26 2013 peter.trommler@ohm-hochschule.de
- fix typo in Group tag
* Fri Aug  2 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.5 from upstream
  * fix LaTeX output issues
  * improved input parsing
  * code refactoring
* Thu May 16 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.3.9 from upstream
  * update to Curry highlighting
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- expand pkg_name macro in "name" tag for Factory submission
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.3.8 from upstream
- requirement for pandoc 1.11
  * support for mozilla rust and Julia
  * updated xml descriptions from kate repository
  * bumped version bound on blaze-html
  * fixed alignment of line numbers with lines
* Sun Nov 18 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.3.3 from upstream
  * clickable line numbers
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.3.2 from upstream
  highlighting-kate 0.5.3.2 (07 Sep 2012)
  * Fixed handling of backslash in bash highlighting.
    Sometimes "\\" is used for backslash in the
    syntax definitions (as in bash), other times "\".
    We now handle both cases.
  highlighting-kate 0.5.3.1 (07 Sep 2012)
  * More changes to properly handle includes.  This
    closes issue #22 with doxygen comments.  pDefault
    has been incorporated into the ends of the context
    parsers, instead of being put in parseExpression.
  * Re-added doxygenlua, which now works.
  highlighting-kate 0.5.3 (07 Sep 2012)
  * Improved handling of include directives.  This fixes
    bugs in comments caused by doxygen and javadoc includes.
  * Changes to internal Types and Common:
  - Context is now a (String, String) rather than a String.
    The first is the syntax name, the second the context name.
  - ContextStack is now a list of Contexts.
  - synStLanguage has been removed.
  - pEndLine parameter has been removed from mkParseSourceLine.
  - parseExpression now handles the endline.
  - parseExpressionInternal has been removed in the
    individual parsers; we now use parseExpression.
  highlighting-kate 0.5.2 (10 Aug 2012)
  * Updated xml syntax definitions from kate repository:
    bash, c, clojure, coffee (formerly coffeescript),
    cpp, doxygen, fortran, go, latex, prolog, r, ruby, tcl.
* Sat Jun 16 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.1 from upstream for pandoc update
  highlighting-kate 0.5.1 (29 May 2012)
  * Fixed inline LaTeX formatting:  it should be `|...|`
    rather than `\Verb{...}`.
  highlighting-kate 0.5.0.6 (27 Apr 2012)
  * Added zenburn style.
  * Updated for compatibility with blaze-html 0.5.*.
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Sat Mar 17 2012 peter.trommler@ohm-hochschule.de
- fixed LICENSE double packaging
* Tue Mar 13 2012 peter.trommler@ohm-hochschule.de
- set option to build executable
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- initial packaging.
